/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package org.objectweb.dream.channel;

import java.io.IOException;
import java.net.UnknownHostException;

/**
 * Attribute controller for <code>ChannelOut</code> components that can send
 * message to only one destination.
 */
public interface MonoDestinationIPChannelOutAttributeController
    extends
      ChannelOutAttributeController
{

  /**
   * Returns the inet address to which messages are sent.
   * 
   * @return a string representation of the inet address to which messages are
   *         sent.
   */
  String getInetAddress();

  /**
   * Sets the inet address to which messages are sent.
   * 
   * @param inetAddress a String representing the inet address.
   * @throws UnknownHostException if the given inet address can't be resolved.
   * @throws IOException if an error occurs while closing the previously used
   *           socket.
   * @see java.net.InetAddress#getByName(java.lang.String)
   */
  void setInetAddress(String inetAddress) throws UnknownHostException,
      IOException;

  /**
   * Returns the port number to which messages are sent.
   * 
   * @return the port number to which messages are sent.
   */
  int getPort();

  /**
   * Sets the port number to which messages are sent.
   * 
   * @param port the port number to which messages are sent.
   */
  void setPort(int port);

}