/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.adl.legacy;

import java.util.List;
import java.util.Map;

import org.objectweb.deployment.scheduling.component.lib.AbstractInstanceProviderTask;
import org.objectweb.fractal.adl.ADLException;
import org.objectweb.fractal.adl.Node;
import org.objectweb.fractal.adl.TaskMap;
import org.objectweb.fractal.adl.components.ComponentContainer;
import org.objectweb.fractal.adl.components.PrimitiveCompiler;
import org.objectweb.fractal.api.control.BindingController;

/**
 * Compiler that register a
 * {@link org.objectweb.deployment.scheduling.component.api.InstanceProviderTask }
 * for legacy component instances.
 */
public class LegacyImplementationCompiler
    implements
      BindingController,
      PrimitiveCompiler
{

  /**
   * Name of the mandatory interface bound to the {@link LegacyComponentBuilder}
   * used by this compiler.
   */
  public static final String       BUILDER_BINDING = "builder";

  protected LegacyComponentBuilder builder;

  /**
   * @see PrimitiveCompiler#compile(List, ComponentContainer, TaskMap, Map)
   */
  public void compile(List path, ComponentContainer container, TaskMap tasks,
      Map context) throws ADLException
  {
    Object legacyInstance = ((Node) container).astGetDecoration("legacy");
    if (legacyInstance != null)
    {
      tasks.addTask("create", container, new LegacyInstanceProviderTask(
          legacyInstance, builder));
    }
  }

  // --------------------------------------------------------------------------
  // Implementation of the BindingController interface
  // --------------------------------------------------------------------------

  /**
   * @see BindingController#listFc()
   */
  public String[] listFc()
  {
    return new String[]{BUILDER_BINDING};
  }

  /**
   * @see BindingController#lookupFc(String)
   */
  public Object lookupFc(final String itf)
  {
    if (itf.equals(BUILDER_BINDING))
    {
      return builder;
    }
    return null;
  }

  /**
   * @see BindingController#bindFc(String, Object)
   */
  public void bindFc(final String itf, final Object value)
  {
    if (itf.equals(BUILDER_BINDING))
    {
      builder = (LegacyComponentBuilder) value;
    }
  }

  /**
   * @see BindingController#unbindFc(String)
   */
  public void unbindFc(final String itf)
  {
    if (itf.equals(BUILDER_BINDING))
    {
      builder = null;
    }
  }

  static class LegacyInstanceProviderTask extends AbstractInstanceProviderTask
  {

    private LegacyComponentBuilder builder;

    /**
     * Creates a instance provider task for the given legacy component.
     * 
     * @param legacyComponent the legacy component, this task is instance
     *          provider.
     */
    public LegacyInstanceProviderTask(Object legacyComponent,
        LegacyComponentBuilder builder)
    {
      setInstance(legacyComponent);
      this.builder = builder;
    }

    /**
     * @see org.objectweb.deployment.scheduling.core.api.Task#execute(Object)
     */
    public void execute(Object ctx) throws Exception
    {
      // stop the legacy component.
      builder.stopComponent(getInstance(), ctx);
    }
  }
}