/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream.message.chunk;

import org.objectweb.dream.message.AbstractChunk;
import org.objectweb.dream.message.Chunk;
import org.objectweb.dream.message.ChunkType;

/**
 * A basic Chunk interface that defines an arrow from a source to a destination.
 */
public class BasicArrowChunk extends AbstractChunk implements ArrowChunk, Chunk
{

  private short arrowFrom;
  private short arrowTo;

  // ---------------------------------------------------------------------------
  // Implementation of the ArrowChunk interface
  // ---------------------------------------------------------------------------

  /**
   * @see ArrowChunk#getArrowFrom()
   */
  public short getArrowFrom()
  {
    return arrowFrom;
  }

  /**
   * @see ArrowChunk#setArrowFrom(short)
   */
  public void setArrowFrom(short from)
  {
    arrowFrom = from;
  }

  /**
   * @see ArrowChunk#getArrowTo()
   */
  public short getArrowTo()
  {
    return arrowTo;
  }

  /**
   * @see ArrowChunk#setArrowTo(short)
   */
  public void setArrowTo(short to)
  {
    arrowTo = to;
  }

  // ---------------------------------------------------------------------------
  // Implementation of the Chunk interface
  // ---------------------------------------------------------------------------

  /**
   * @see Chunk#getType()
   */
  public ChunkType getType()
  {
    return ArrowChunk.TYPE;
  }

  /**
   * @see Chunk#recycle()
   */
  public void recycle()
  {
  }

  /**
   * @see Chunk#transfertState(Chunk)
   */
  public void transfertState(Chunk newInstance)
  {
    ArrowChunk newInst = (ArrowChunk) newInstance;
    newInst.setArrowFrom(getArrowFrom());
    newInst.setArrowTo(getArrowTo());
  }

}