/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.message.codec;

import java.io.Externalizable;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

import org.objectweb.dream.AbstractComponent;
import org.objectweb.dream.message.Message;
import org.objectweb.dream.message.manager.MessageManager;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.IllegalBindingException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;

/**
 * Encoder/decoder that can be used with
 * {@link org.objectweb.dream.message.manager.PoolNonExtensibleMessageManagerImpl}.
 * It supposes that every messages are instances of the same class, and this
 * class implements {@link Externalizable}. It also supposes that streams are
 * {@link ObjectInput }or {@link ObjectOutput}.
 */
public class BasicNonExtensibleMessageCodecImpl extends AbstractComponent
    implements
      MessageCodec
{

  protected MessageManager messageManagerItf;

  /**
   * @see MessageCodec#encode(Object, Message)
   */
  public void encode(Object stream, Message message) throws IOException
  {
    ((Externalizable) message).writeExternal((ObjectOutput) stream);
  }

  /**
   * @see MessageCodec#decode(Object)
   */
  public Message decode(Object stream) throws IOException
  {
    Message msg = messageManagerItf.createMessage(null);
    try
    {
      ((Externalizable) msg).readExternal((ObjectInput) stream);
    }
    catch (ClassNotFoundException e)
    {
      throw new IOException("Unable to decode message : "
          + e.getLocalizedMessage());
    }
    return msg;
  }

  // ---------------------------------------------------------------------------
  // Implementation of BindingController interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.fractal.api.control.BindingController#listFc()
   */
  public String[] listFc()
  {
    return new String[]{MessageManager.ITF_NAME};
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#bindFc(String,
   *      Object)
   */
  public synchronized void bindFc(String clientItfName, Object serverItf)
      throws NoSuchInterfaceException, IllegalBindingException,
      IllegalLifeCycleException
  {
    if (clientItfName.equals(MessageManager.ITF_NAME))
    {
      messageManagerItf = (MessageManager) serverItf;
    }
    super.bindFc(clientItfName, serverItf);
  }

}