/**
 * Copyright (C) 2002 
 */

package org.objectweb.util.monolog.api;

/**
 * It manages Level instances.
 *
 * @author Sebastien Chassande-Barrioz
 */
public interface LevelFactory {

	/**
	 * It defines a new Level with a name and an integer value.
	 * @param name is the name of the new level
	 * @param value is the integer value of the new level
	 * @return a Level instance or a null value if It exists a Level with the
	 * same name but with another integer value.
	 */
	Level defineLevel(String name, int value);

	/**
	 * It defines a new Level with a name and a string value. The string value
	 * is analyzed to obtain the integer value.
	 * @param name is the name of the new level
	 * @param value is the string value of the new level
	 * @return a Level instance or a null value if It exists a Level with the
	 * same name but with another integer value.
	 */
	Level defineLevel(String name, String value);

	/**
	 * It retrieves a Level instance which the name is equals to the parameter.
	 * @param name is the name of request Level
	 * @return a Leve instance or a null value if the level does not exist.
	 */
	Level getLevel(String name);

	/**
	 * It retrieves a Level instance which the integer value is equals to the
	 * parameter.
	 * @param value is the integer value of request Level
	 * @return a Leve instance or a null value if the level does not exist. As
	 * it is possible to define several Levels which have the same integer value
	 * this methods returns the Level instance of first name found in the list.
	 */
	Level getLevel(int value);

	/**
	 * It retrieves all Level instances defined in this manager.
	 */
	Level[] getLevels();

	/**
	 * It removes a Level instance to this manager.
	 */
	void removeLevel(String name);

}
